@@ -142,6 +142,9 @@ void AptInterface::procFinished(int exitCode, QProcess::ExitStatus exitStatus)
 		} else if( output.contains("E: Broken packages") ) {
 			iMainWindow->operationFinished(lastMode, false, "<b>Broken packages</b><br>" \
 										   "Your system has broken packages, see log for details");
+		} else if( output.contains("E: Handler silently failed") ) {
+			iMainWindow->operationFinished(lastMode, false, "<b>Handler silently failed</b><br>" \
+										   "This happens if you try to install from the forbidden user/hidden category");
 		} else {
 			iError.setNum(exitCode);
 			iError.prepend(tr("Exit code "));
@@ -261,7 +264,7 @@ bool AptInterface::readDpkgDatabase()
 
 bool AptInterface::processPackageDataLine(Package*& pkg, QByteArray& line, multiLine& multiline, bool dpkg)
 {
-	if( !line.startsWith(" ") )
+	if( !line.startsWith(' ') && !line.startsWith('\t') )
 		line = line.trimmed();
 
 	if( line.startsWith("Package: ") )
@@ -321,14 +324,17 @@ bool AptInterface::processPackageDataLine(Package*& pkg, QByteArray& line, multi
 	}
 
 	if( multiline == MultiLineDesc ) {
-		if( line.startsWith(" ") && line.trimmed()!="" ) {
-			pkg->appendDescLong( line.trimmed() + " " );
+		if( (line.startsWith(' ') || line.startsWith('\t')) && line.trimmed()!="" ) {
+			if( line.trimmed()!="." )
+				pkg->appendDescLong( line.trimmed() + "\n" );
+			else
+				pkg->appendDescLong( "\n" );
 		} else {
 			multiline = MultiLineNone;
 		}
 	}
 	if( multiline == MultiLineIcon ) {
-		if( line.startsWith(" ") && line.trimmed()!="" ) {
+		if( (line.startsWith(' ') || line.startsWith('\t')) && line.trimmed()!="" ) {
 			pkg->appendIconData( line.trimmed() );
 		} else {
 			multiline = MultiLineNone;
@@ -337,7 +343,7 @@ bool AptInterface::processPackageDataLine(Package*& pkg, QByteArray& line, multi
 
 	if( line.startsWith("Description: ") && pkg != 0 && pkg->descShort()=="" )
 	{
-		pkg->setDescShort( line.mid(13) );
+		pkg->setDescShort( line.mid(13).trimmed() );
 		multiline = MultiLineDesc;
 	}
 	if( line.startsWith("Maemo-Icon-26:") && pkg != 0 && !pkg->hasIconData() )
