@@ -353,8 +353,12 @@ void MainWindow::on_actionOptions_triggered()
 
 void MainWindow::GdkEventIconThemeReload()
 {
+	// This feature does not work when compiled on the Qt SDK in Ubuntu.
+	// Only works when compiled in scratchbox or by the maemo.org autobuilder.
+
 #ifdef MYDEF_GTK_EXISTS
-	std::cout << "Sending GDK client event" << std::endl;
+	//std::cout << "Sending GDK client icon theme reload event" << std::endl;
+
 	GdkEventClient ev;
 	ev.type = GDK_CLIENT_EVENT;
 	ev.window = NULL;
