@@ -30,6 +30,7 @@ class Uninstall;
 class Dialog;
 class dimmer;
 class RepoView;
+class Settings;
 
 
 namespace Ui {
@@ -49,6 +50,7 @@ public:
 	void busyDialog(bool visible_, QString title="", QString text="");
 	void setOperation(operation op_) { iOperation=op_; }
 	void closeEvent(QCloseEvent *event);
+	void GdkEventIconThemeReload();
 
 public slots:
 	void on_btnUpdate_clicked();
@@ -62,13 +64,15 @@ private:
 	PackageView* iWinPackageView;
 	RepoView* iWinRepoView;
 	Dialog* iDlgBusy;
+	Settings* iSettings;
 	operation iOperation;
 	dimmer* iDimmer;
 	bool iReposAutoUpdating;
 	bool iUpgradeAutoUpdate;
 
 private slots:
-	void on_actionView_log_triggered();
+	void on_actionOptions_triggered();
+ void on_actionView_log_triggered();
 	void on_btnRepos_clicked();
 	void on_actionClean_triggered();
 	void on_actionAbout_triggered();
