@@ -21,43 +21,73 @@
 #define PACKAGE_H
 
 #include <QtCore>
+class AptInterface;
 
 class Package
 {
 public:
-	Package(QString name_);
+	enum operation { PkgOpNone, PkgOpInstallUpgrade, PkgOpRemove };
+
+	// the order must match status filter strings
+	enum packageStatus { PkgStatUnknown, PkgStatNotInstalled, PkgStatUpgradeable, PkgStatInstalled };
+
+	Package(QString name_, AptInterface* apt_);
 	~Package();
 	void setMaemoDisplayName(QString n_) { iMaemoDisplayName=n_; }
 	void setInstalled(bool i_) { iIsInstalled=i_; }
 	void setLocal(bool l_) { iIsLocal=l_; }
-	void setMarkedForOperation(bool o_) { iMarkedForOperation=o_; }
+	void setMarkedForOperation(operation op_);
 	void setVersionInstalled(QString v_) { iVersionInstalled=v_; }
 	void setVersionAvailable(QString v_) { iVersionAvailable=v_; }
 	void setDescShort(QString d_) { iDescriptionShort=d_; }
-	void setDescLong(QString d_) { iDescriptionLong=d_; }
+	void appendDescLong(QString d_) { iDescriptionLong.append(d_); }
 	void setSection(QString s_) { iSection=s_; }
+	void setSize(int i_) { iSize=i_; }
+	void setInstalledSize(int i_) { iInstalledSize=i_; }
+	void appendIconData(QByteArray d_) { iIconData.append(d_); }
+	void updateStatus();
+
+	void convertIcon();
+	void printDebugInfo();
+
 	QString name() { return iName; }
 	QString maemoDisplayName() { return iMaemoDisplayName; }
 	bool isInstalled() { return iIsInstalled; }
 	bool isLocal() { return iIsLocal; }
 	bool isMarkedForOperation() { return iMarkedForOperation; }
+	operation markedOperation() { return iMarkedOperation; }
 	QString versionInstalled() { return iVersionInstalled; }
 	QString versionAvailable() { return iVersionAvailable; }
 	QString descShort() { return iDescriptionShort; }
 	QString descLong() { return iDescriptionLong; }
 	QString section() { return iSection; }
+	int size() { return iSize; }
+	int installedSize() { return iSize; }
+	QPixmap* icon() { return &iIcon; }
+	bool hasIconData();
+	bool isUpgradeable();
+	packageStatus status() { return iPkgStatus; }
 
 private:
+	AptInterface* iAptInterface;
+
 	QString iName;
 	QString iMaemoDisplayName;
 	bool iIsInstalled;
 	bool iIsLocal;
 	bool iMarkedForOperation;
+	packageStatus iPkgStatus;
 	QString iVersionAvailable;
 	QString iVersionInstalled;
 	QString iDescriptionShort;
 	QString iDescriptionLong;
 	QString iSection;
+	int iSize;
+	int iInstalledSize;
+	operation iMarkedOperation;
+
+	QByteArray iIconData;
+	QPixmap iIcon;
 
 };
 
