@@ -69,10 +69,12 @@ PackageSelector::PackageSelector(Package* pkg, QWidget *parent) :
 	}
 
 	longtext += "<br>";
-	if( pkg->descLong()!="" ) longtext+="<u>";
 	longtext += pkg->descShort();
-	if( pkg->descLong()!="" ) longtext+="</u>";
-	longtext += "<br>" + pkg->descLong();
+	QString descLong = pkg->descLong();
+	if( descLong.length()>0 ) {
+		descLong.replace('\n',"<br>");
+		longtext += "<br><font size=\"-1\"><br>" + descLong + "</font>";
+	}
 
 	ui->label_text->setText( longtext );
 
