@@ -42,7 +42,6 @@ void ListItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &opti
 	Package::operation marked = (Package::operation) index.data(UserRoleMarked).toInt();
 	bool installed = index.data(UserRoleInstalled).toBool();
 	bool upgradeable = index.data(UserRoleUpgradeable).toBool();
-	//int oper = index.data(UserRoleOperation).toInt();
 
 	painter->save();
 	QRect r = option.rect;
@@ -376,8 +375,6 @@ void PackageView::addListItem(Package* pkg_, QString listname_)
 		p->setData(UserRoleName, listname_);
 	}
 
-	//p->setData(UserRoleOperation, iOperation);
-
 	if( pkg_ != 0 ) {
 		p->setData(UserRoleDescShort, pkg_->descShort());
 		p->setData(UserRoleVerAvail, pkg_->versionAvailable());
@@ -489,12 +486,7 @@ void PackageView::on_listWidget_itemClicked(QListWidgetItem* item)
 	s.exec();
 
 	static_cast<PackageListWidgetItem*>(item)->package()->setMarkedForOperation( s.selectedOperation() );
-
-	if( static_cast<PackageListWidgetItem*>(item)->package()->isMarkedForOperation() ) {
-		static_cast<PackageListWidgetItem*>(item)->setData(UserRoleMarked, (int)s.selectedOperation());
-	} else {
-		static_cast<PackageListWidgetItem*>(item)->setData(UserRoleMarked, (int)s.selectedOperation());
-	}
+	item->setData(UserRoleMarked, (int)s.selectedOperation());
 
 	updateLabel();
 }
@@ -623,7 +615,11 @@ void PackageView::on_lineEdit_textEdited(QString text)
 	}
 
 	iPrevSearchText = text;
-	QList<QListWidgetItem*> results = ui->listWidget->findItems( text, Qt::MatchContains );
+	QList<QListWidgetItem*> results;
+	if( text.startsWith(":") )
+		results = ui->listWidget->findItems( text.mid(1), Qt::MatchStartsWith );
+	else
+		results = ui->listWidget->findItems( text, Qt::MatchContains );
 
 	ui->searchLabel->setText( QString("%0 results").arg(results.count()) );
 
