@@ -35,7 +35,7 @@ class Package;
 class dimmer;
 class KeyEventGrabber;
 
-enum UserRoles { UserRoleName=Qt::UserRole, UserRoleVerInst, UserRoleVerAvail, UserRoleDescShort, UserRoleOperation,
+enum UserRoles { UserRoleName=Qt::UserRole, UserRoleVerInst, UserRoleVerAvail, UserRoleDescShort,
 				 UserRoleMarked, UserRoleInstalled, UserRoleUpgradeable };
 
 
